====================================
Disspcap - pcap dissector
====================================

`Disspcap <https://github.com/danieluhricek/disspcap>`_ is a minimalist library for packet examination implemented in C++ and with available binding to Python. 
Attempting to be *simple* and *fast*. Disspcap provides simple alternative to robust
pcap-related libraries and frameworks.


Python package
**************

.. code:: bash

    $ pip install disspcap


Docs
****
`<https://disspcap.readthedocs.io>`_